@@ -4,7 +4,7 @@
 //  Core drawing code for Aven.
 //
 //  Copyright (C) 2000-2001,2002,2005 Mark R. Shinwell.
-//  Copyright (C) 2001-2004,2005,2006,2007,2010,2011,2012,2013,2014,2015,2016 Olly Betts
+//  Copyright (C) 2001-2004,2005,2006,2007,2010,2011,2012,2013,2014,2015,2016,2017 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -103,9 +103,18 @@ enum {
 };
 
 enum {
-      SPLAYS_HIDE,
-      SPLAYS_SHOW_FADED,
-      SPLAYS_SHOW_NORMAL,
+    SHOW_HIDE,
+    SHOW_DASHED,
+    SHOW_FADED,
+    SHOW_NORMAL,
+};
+
+struct Split {
+    Vector3 vec;
+    glaCoord tx, ty;
+
+    Split(const Vector3& vec_, glaCoord tx_, glaCoord ty_)
+	: vec(vec_), tx(tx_), ty(ty_) { }
 };
 
 // It's pointless to redraw the screen as often as we can on a fast machine,
@@ -180,6 +189,7 @@ private:
     bool m_Crosses;
     bool m_Legs;
     int m_Splays;
+    int m_Dupes;
     bool m_Names;
     bool m_Scalebar;
     bool m_ColourKey;
@@ -258,11 +268,14 @@ private:
     size_t n_tris;
 
     void PlaceVertexWithColour(const Vector3 &v, Double factor = 1.0);
-    void PlaceVertexWithColour(const Vector3 & v, GLint tex_x, GLint tex_y,
+    void PlaceVertexWithColour(const Vector3 & v,
+			       glaTexCoord tex_x, glaTexCoord tex_y,
 			       Double factor);
     void SetDepthColour(Double z, Double factor);
     void PlaceVertexWithDepthColour(const Vector3 & v, Double factor = 1.0);
-    void PlaceVertexWithDepthColour(const Vector3 & v, GLint tex_x, GLint tex_y, Double factor);
+    void PlaceVertexWithDepthColour(const Vector3 & v,
+				    glaTexCoord tex_x, glaTexCoord tex_y,
+				    Double factor);
 
     void SetColourFrom01(double how_far, Double factor);
 
@@ -278,9 +291,8 @@ private:
     void SkinPassage(vector<XSect> & centreline, bool draw = true);
 
     virtual void GenerateList(unsigned int l);
-    void GenerateDisplayList();
+    void GenerateDisplayList(bool surface);
     void GenerateDisplayListTubes();
-    void GenerateDisplayListSurface();
     void DrawTerrainTriangle(const Vector3 & a, const Vector3 & b, const Vector3 & c);
     void DrawTerrain();
     void GenerateDisplayListShadow();
@@ -436,11 +448,13 @@ public:
 
     bool HasUndergroundLegs() const;
     bool HasSplays() const;
+    bool HasDupes() const;
     bool HasSurfaceLegs() const;
     bool HasTubes() const;
 
     bool ShowingUndergroundLegs() const { return m_Legs; }
     int ShowingSplaysMode() const { return m_Splays; }
+    int ShowingDupesMode() const { return m_Dupes; }
     bool ShowingSurfaceLegs() const { return m_Surface; }
 
     bool ShowingColourKey() const { return m_ColourKey; }
@@ -460,6 +474,14 @@ public:
     void SetSplaysMode(int mode) {
 	m_Splays = mode;
 	UpdateBlobs();
+	InvalidateList(LIST_SURFACE_LEGS);
+	InvalidateList(LIST_UNDERGROUND_LEGS);
+	ForceRefresh();
+    }
+    void SetDupesMode(int mode) {
+	m_Dupes = mode;
+	UpdateBlobs();
+	InvalidateList(LIST_SURFACE_LEGS);
 	InvalidateList(LIST_UNDERGROUND_LEGS);
 	ForceRefresh();
     }
@@ -533,6 +555,11 @@ public:
     void SplitLineAcrossBands(int band, int band2,
 			      const Vector3 &p, const Vector3 &q,
 			      Double factor = 1.0);
+    void SplitPolyAcrossBands(vector<vector<Split> >& splits,
+			      int band, int band2,
+			      const Vector3 &p, const Vector3 &q,
+			      glaTexCoord ptx, glaTexCoord pty,
+			      glaTexCoord w, glaTexCoord h);
     int GetDepthColour(Double z) const;
     Double GetDepthBoundaryBetweenBands(int a, int b) const;
     void AddPolyline(const traverse & centreline);
